@@ -1,4 +1,4 @@
-package News::Pictures;
+package News::Pictures;perl
 
 use warnings;
 #use strict;
@@ -11,11 +11,11 @@ News::Pictures - The great new News::Pictures!
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 =head1 SYNOPSIS
